;***********************************************************************
;Multi-Agent System to Simulate the Human Behaviour within a Work Team
;version 2.0
;
;This is the file with Fuzzy Rules to change the Internal State of the Agent
;according to the Assigned Tasks Parameters, Kind of Agent, and Personality of
;of the agent.
;
;@author: Juan C. Martinez Miranda.
;         juan.martinez.miranda@gmail.com
;Institution: Universdad Complutense de Madrid
;             Facultad de Informtica.
;Winter 2010.

************************************************************************/

(defglobal ?*FExperience* = (new nrc.fuzzy.FuzzyVariable "experience" 0.0 100.0))
(defglobal ?*FDrive* = (new nrc.fuzzy.FuzzyVariable "drive" 0.0 100.0))
(defglobal ?*FInfluence* = (new nrc.fuzzy.FuzzyVariable "influence" 0.0 100.0))
(defglobal ?*FStainess* = (new nrc.fuzzy.FuzzyVariable "stainess" 0.0 100.0))
(defglobal ?*FCompliance* = (new nrc.fuzzy.FuzzyVariable "compliance" 0.0 100.0))
(defglobal ?*FAloneTeam* = (new nrc.fuzzy.FuzzyVariable "aloneteam" 0.0 100.0))
(defglobal ?*FIntExt* = (new nrc.fuzzy.FuzzyVariable "introverted" 0.0 100.0))
(defglobal ?*FDuration* = (new nrc.fuzzy.FuzzyVariable "duration" -30.0 30.0))
(defglobal ?*FTaskType* = (new nrc.fuzzy.FuzzyVariable "tasktype" 0.0 100.0))
(defglobal ?*FTaskDifficult* = (new nrc.fuzzy.FuzzyVariable "taskdifficult" 0.0 100.0))

(defglobal ?*ChangeDesire* = (new nrc.fuzzy.FuzzyVariable "ChangeDesire" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeInterest* = (new nrc.fuzzy.FuzzyVariable "ChangeInterest" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeDisgust* = (new nrc.fuzzy.FuzzyVariable "ChangeDisgust" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeAnxiety* = (new nrc.fuzzy.FuzzyVariable "ChangeAnxiety" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeStress* = (new nrc.fuzzy.FuzzyVariable "ChangeStress" -30.0 30.0 "Intensity"))

(defglobal ?*rulesThatFired* = "")

(defrule init
   (inicio)
  =>
   (import nrc.fuzzy.*)
   (load-package nrc.fuzzy.jess.FuzzyFunctions)
   (?*FDuration* addTerm "HighAdvance" (new ZFuzzySet -30.0 -10.0))
   (?*FDuration* addTerm "LowAdvance" (new PIFuzzySet -7.5 7.5))
   (?*FDuration* addTerm "Normal" (new PIFuzzySet 0.0 5.0))
   (?*FDuration* addTerm "LowDelay" (new PIFuzzySet 7.5 7.5))
   (?*FDuration* addTerm "HighDelay" (new SFuzzySet 10.0 30.0))
   (?*FExperience* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FExperience* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FExperience* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FDrive* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FDrive* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FDrive* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FInfluence* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FInfluence* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FInfluence* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FStainess* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FStainess* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FStainess* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FCompliance* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FCompliance* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FCompliance* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FAloneTeam* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FAloneTeam* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FAloneTeam* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FIntExt* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FIntExt* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FIntExt* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FTaskType* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FTaskType* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FTaskType* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FTaskDifficult* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FTaskDifficult* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FTaskDifficult* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*ChangeDesire* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeDesire* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeDesire* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeDesire* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeDesire* addTerm "HighUp" (new SFuzzySet 15.0 30.0))
   (?*ChangeInterest* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeInterest* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeInterest* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeInterest* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeInterest* addTerm "HighUp" (new SFuzzySet 15.0 30.0))
   (?*ChangeDisgust* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeDisgust* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeDisgust* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeDisgust* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeDisgust* addTerm "HighUp" (new SFuzzySet 15.0 30.0))
   (?*ChangeAnxiety* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeAnxiety* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeAnxiety* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeAnxiety* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeAnxiety* addTerm "HighUp" (new SFuzzySet 15.0 30.0))
   (?*ChangeStress* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeStress* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeStress* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeStress* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeStress* addTerm "HighUp" (new SFuzzySet 15.0 30.0))

   (store DURATIONFUZZYVARIABLE ?*FDuration*)
   (store EXPERIENCEFUZZYVARIABLE ?*FExperience*)
   (store DRIVEFUZZYVARIABLE ?*FDrive*)
   (store INFLUENCEFUZZYVARIABLE ?*FInfluence*)
   (store STAINESSFUZZYVARIABLE ?*FStainess*)
   (store COMPLIANCEFUZZYVARIABLE ?*FCompliance*)
   (store ALONETEAMFUZZYVARIABLE ?*FAloneTeam*)
   (store INTEXTFUZZYVARIABLE ?*FIntExt*)

   (store TASKTYPEFUZZYVARIABLE ?*FTaskType*)
   (store TASKDIFFICULTFUZZYVARIABLE ?*FTaskDifficult*)
)

(defrule high_advance_duration_high_drive
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH HIGH DRIVER; ")
  )
)


(defrule high_advance_duration_medium_drive
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH MEDIUM DRIVER; ")
  )
)


(defrule high_advance_duration_low_drive
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH LOW DRIVER; ")
  )
)


(defrule high_advance_duration_high_influence
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH HIGH EXPRESSIVE; ")
  )
)


(defrule high_advance_duration_medium_influence
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH MEDIUM EXPRESSIVE; ")
  )
)


(defrule high_advance_duration_low_influence
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH LOW EXPRESSIVE; ")
  )
)


(defrule high_advance_duration_high_stainess
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH HIGH AMIABLE; ")
  )
)


(defrule high_advance_duration_medium_stainess
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH MEDIUM AMIABLE; ")
  )
)


(defrule high_advance_duration_low_stainess
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH LOW AMIABLE; ")
  )
)


(defrule high_advance_duration_high_compliance
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH HIGH ANALYTICAL; ")
  )
)


(defrule high_advance_duration_medium_compliance
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH MEDIUM ANALYTICAL; ")
  )
)

(defrule high_advance_duration_low_compliance
  (and (advance ?a&:(fuzzy-match ?a "HighAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE WITH LOW ANALYTICAL; ")
  )
)


(defrule low_advance_duration_high_drive
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH HIGH DRIVER; ")
  )
)


(defrule low_advance_duration_medium_drive
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH MEDIUM DRIVER; ")
  )
)


(defrule low_advance_duration_low_drive
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH LOW DRIVER; ")
  )
)


(defrule low_advance_duration_high_influence
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH HIGH EXPRESSIVE; ")
  )
)


(defrule low_advance_duration_medium_influence
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH MEDIUM EXPRESSIVE; ")
  )
)


(defrule low_advance_duration_low_influence
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH LOW EXPRESSIVE; ")
  )
)


(defrule low_advance_duration_high_stainess
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH HIGH AMIABLE; ")
  )
)


(defrule low_advance_duration_medium_stainess
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH MEDIUM AMIABLE; ")
  )
)


(defrule low_advance_duration_low_stainess
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH LOW AMIABLE; ")
  )
)


(defrule low_advance_duration_high_compliance
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH HIGH ANALYTICAL; ")
  )
)


(defrule low_advance_duration_medium_compliance
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH MEDIUM ANALYTICAL; ")
  )
)

(defrule low_advance_duration_low_compliance
  (and (advance ?a&:(fuzzy-match ?a "LowAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE WITH LOW ANALYTICAL; ")
  )
)


(defrule normal_duration_high_drive
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH HIGH DRIVER; ")
  )
)


(defrule normal_duration_medium_drive
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH MEDIUM DRIVER; ")
  )
)


(defrule normal_duration_low_drive
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH LOW DRIVER; ")
  )
)


(defrule normal_duration_high_influence
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH HIGH EXPRESSIVE; ")
  )
)


(defrule normal_duration_medium_influence
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH MEDIUM EXPRESSIVE; ")
  )
)


(defrule normal_duration_low_influence
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH LOW EXPRESSIVE; ")
  )
)


(defrule normal_duration_high_stainess
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH HIGH AMIABLE; ")
  )
)


(defrule normal_duration_medium_stainess
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH MEDIUM AMIABLE; ")
  )
)


(defrule normal_duration_low_stainess
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH LOW AMIABLE; ")
  )
)


(defrule normal_duration_high_compliance
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH HIGH ANALYTICAL; ")
  )
)


(defrule normal_duration_medium_compliance
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH MEDIUM ANALYTICAL; ")
  )
)

(defrule normal_duration_low_compliance
  (and (advance ?a&:(fuzzy-match ?a "Normal"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL DURATION WITH LOW ANALYTICAL; ")
  )
)


(defrule low_delay_duration_high_drive
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH HIGH DRIVER; ")
  )
)


(defrule low_delay_duration_medium_drive
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH MEDIUM DRIVER; ")
  )
)


(defrule low_delay_duration_low_drive
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH LOW DRIVER; ")
  )
)


(defrule low_delay_duration_high_influence
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH HIGH EXPRESSIVE; ")
  )
)


(defrule low_delay_duration_medium_influence
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH MEDIUM EXPRESSIVE; ")
  )
)


(defrule low_delay_duration_low_influence
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH LOW EXPRESSIVE; ")
  )
)


(defrule low_delay_duration_high_stainess
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH HIGH AMIABLE; ")
  )
)


(defrule low_delay_duration_medium_stainess
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH MEDIUM AMIABLE; ")
  )
)


(defrule low_delay_duration_low_stainess
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH LOW AMIABLE; ")
  )
)


(defrule low_delay_duration_high_compliance
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH HIGH ANALYTICAL; ")
  )
)


(defrule low_delay_duration_medium_compliance
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH MEDIUM ANALYTICAL; ")
  )
)

(defrule low_delay_duration_low_compliance
  (and (advance ?a&:(fuzzy-match ?a "LowDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY WITH LOW ANALYTICAL; ")
  )
)


(defrule high_delay_duration_high_drive
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH HIGH DRIVER; ")
  )
)


(defrule high_delay_duration_medium_drive
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH MEDIUM DRIVER; ")
  )
)


(defrule high_delay_duration_low_drive
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH LOW DRIVER; ")
  )
)


(defrule high_delay_duration_high_influence
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH HIGH EXPRESSIVE; ")
  )
)


(defrule high_delay_duration_medium_influence
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH MEDIUM EXPRESSIVE; ")
  )
)


(defrule high_delay_duration_low_influence
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH LOW EXPRESSIVE; ")
  )
)


(defrule high_delay_duration_high_stainess
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH HIGH AMIABLE; ")
  )
)


(defrule high_delay_duration_medium_stainess
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH MEDIUM AMIABLE; ")
  )
)


(defrule high_delay_duration_low_stainess
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH LOW AMIABLE; ")
  )
)


(defrule high_delay_duration_high_compliance
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH HIGH ANALYTICAL; ")
  )
)


(defrule high_delay_duration_medium_compliance
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH MEDIUM ANALYTICAL; ")
  )
)

(defrule high_delay_duration_low_compliance
  (and (advance ?a&:(fuzzy-match ?a "HighDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY WITH LOW ANALYTICAL; ")
  )
)


(defrule high_drive_alone
  (and (drive ?dr&:(eq ?dr "High"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighDown"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WORKING ALONE; ")
  )
)


(defrule medium_drive_alone
  (and (drive ?dr&:(eq ?dr "Medium"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WORKING ALONE; ")
  )
)


(defrule low_drive_alone
  (and (drive ?dr&:(eq ?dr "Low"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WORKING ALONE; ")
  )
)


(defrule high_influence_alone
  (and (influence ?inf&:(eq ?inf "High"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighDown"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighDown"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WORKING ALONE; ")
  )
)


(defrule medium_influence_alone
  (and (influence ?inf&:(eq ?inf "Medium"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WORKING ALONE; ")
  )
)


(defrule low_influence_alone
  (and (influence ?inf&:(eq ?inf "Low"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WORKING ALONE; ")
  )
)


(defrule high_stainess_alone
  (and (stainess ?stss&:(eq ?stss "High"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WORKING ALONE; ")
  )
)


(defrule medium_stainess_alone
  (and (stainess ?stss&:(eq ?stss "Medium"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WORKING ALONE; ")
  )
)


(defrule low_stainess_alone
  (and (stainess ?stss&:(eq ?stss "Low"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WORKING ALONE; ")
  )
)


(defrule high_compliance_alone
  (and (compliance ?cmpl&:(eq ?cmpl "High"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WORKING ALONE; ")
  )
)


(defrule medium_compliance_alone
  (and (compliance ?cmpl&:(eq ?cmpl "Medium"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WORKING ALONE; ")
  )
)


(defrule low_compliance_alone
  (and (compliance ?cmpl&:(eq ?cmpl "Low"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WORKING ALONE; ")
  )
)


(defrule high_drive_team
  (and (drive ?dr&:(eq ?dr "High"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WORKING IN TEAM; ")
  )
)


(defrule medium_drive_team
  (and (drive ?dr&:(eq ?dr "Medium"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WORKING IN TEAM; ")
  )
)


(defrule low_drive_team
  (and (drive ?dr&:(eq ?dr "Low"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WORKING IN TEAM; ")
  )
)


(defrule high_influence_team
  (and (influence ?inf&:(eq ?inf "High"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WORKING IN TEAM; ")
  )
)


(defrule medium_influence_team
  (and (influence ?inf&:(eq ?inf "Medium"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WORKING IN TEAM; ")
  )
)


(defrule low_influence_team
  (and (influence ?inf&:(eq ?inf "Low"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighDown"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WORKING IN TEAM; ")
  )
)


(defrule high_stainess_team
  (and (stainess ?stss&:(eq ?stss "High"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WORKING IN TEAM; ")
  )
)


(defrule medium_stainess_team
  (and (stainess ?stss&:(eq ?stss "Medium"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WORKING ALONE; ")
  )
)


(defrule low_stainess_team
  (and (stainess ?stss&:(eq ?stss "Low"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WORKING IN TEAM; ")
  )
)


(defrule high_compliance_team
  (and (compliance ?cmpl&:(eq ?cmpl "High"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WORKING IN TEAM; ")
  )
)


(defrule medium_compliance_team
  (and (compliance ?cmpl&:(eq ?cmpl "Medium"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WORKING IN TEAM; ")
  )
)


(defrule low_compliance_team
  (and (compliance ?cmpl&:(eq ?cmpl "Low"))
       (aloneteam ?at&:(= ?at 0))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WORKING IN TEAM; ")
  )
)


(defrule pref_aloneteam_positive
  (and (prefersalone ?pa&:(eq ?pa "Low"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " PREFERS TO WORK ALONE = TRUE; ")
  )
)

(defrule pref_aloneteam_negative
  (and (prefersalone ?pa&:(eq ?pa "High"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighDown"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighDown"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " PREFERS TO WORK IN TEAM = FALSE; ")
  )
)

(defrule intro_aloneteam_positive
  (and (introextro ?intext&:(eq ?intext "Low"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " INTROVERTED AND WORKS ALONE; ")
  )
)

(defrule intro_aloneteam_negative
  (and (introextro ?intext&:(eq ?intext "High"))
       (aloneteam ?at&:(= ?at 1))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " INTROVERTED AND WORKS IN TEAM; ")
  )
)


(defrule high_medium_experience_low_complex_task
  (and (kindoftask ?kt&:(fuzzy-match ?kt "Low"))
       (experience ?ex&:(or (fuzzy-match ?ex "Medium")
                            (fuzzy-match ?ex "High")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW COMPLEX TASK AND HAVE EXPERIENCE; ")
  )
)

(defrule low_experience_low_complex_task
  (and (kindoftask ?kt&:(fuzzy-match ?kt "Low"))
       (experience ?ex&:(fuzzy-match ?ex "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW COMPLEX TASK AND LOW EXPERIENCE; ")
  )
)

(defrule high_medium_experience_medium_complex_task
  (and (kindoftask ?kt&:(fuzzy-match ?kt "Medium"))
       (experience ?ex&:(or (fuzzy-match ?ex "Medium")
                            (fuzzy-match ?ex "High")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM COMPLEX TASK AND HAVE EXPERIENCE; ")
  )
)

(defrule low_experience_medium_complex_task
  (and (kindoftask ?kt&:(fuzzy-match ?kt "Medium"))
       (experience ?ex&:(fuzzy-match ?ex "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM COMPLEX TASK AND LOW EXPERIENCE; ")
  )
)

(defrule high_medium_experience_high_complex_task
  (and (kindoftask ?kt&:(fuzzy-match ?kt "High"))
       (experience ?ex&:(or (fuzzy-match ?ex "Medium")
                            (fuzzy-match ?ex "High")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH COMPLEX TASK AND HAVE EXPERIENCE; ")
  )
)

(defrule low_experience_high_complex_task
  (and (kindoftask ?kt&:(fuzzy-match ?kt "High"))
       (experience ?ex&:(fuzzy-match ?ex "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH COMPLEX TASK AND LOW EXPERIENCE; ")
  )
)

(defrule projmng_coor_low_specialised_task
  (and (typetask ?tt&:(fuzzy-match ?tt "Low"))
       (typeagent ?tag&:(or (eq ?tag "PROJECT MANAGER")
                            (eq ?tag "COORDINATOR")
                            (eq ?tag "SPECIALIST Sr.")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighDown"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighDown"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " PROJECT MANAGER OR COORDINATOR OR SPECIALIST Sr. AND LOW SPECIALISED TASK; ")
  )
)

(defrule projmng_coor_medium_specialised_task
  (and (typetask ?tt&:(fuzzy-match ?tt "Medium"))
       (typeagent ?tag&:(or (eq ?tag "PROJECT MANAGER")
                            (eq ?tag "COORDINATOR")
                            (eq ?tag "SPECIALIST Sr.")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " PROJECT MANAGER OR COORDINATOR OR SPECIALIST Sr. AND MEDIUM SPECIALISED TASK; ")
  )
)

(defrule projmng_coor_high_specialised_task
  (and (typetask ?tt&:(fuzzy-match ?tt "High"))
       (typeagent ?tag&:(or (eq ?tag "PROJECT MANAGER")
                            (eq ?tag "COORDINATOR")
                            (eq ?tag "SPECIALIST Sr.")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " PROJECT MANAGER OR COORDINATOR OR SPECIALIST Sr. AND HIGH SPECIALISED TASK; ")
  )
)

(defrule specialist_jr_low_specialised_task
  (and (typetask ?tt&:(fuzzy-match ?tt "Low"))
       (typeagent ?tag&:(eq ?tag "SPECIALIST Jr."))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " SPECIALIST Jr. AND LOW SPECIALISED TASK; ")
  )
)

(defrule specialist_jr_medium_specialised_task
  (and (typetask ?tt&:(fuzzy-match ?tt "Medium"))
       (typeagent ?tag&:(eq ?tag "SPECIALIST Jr."))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " SPECIALIST Jr. AND MEDIUM SPECIALISED TASK; ")
  )
)

(defrule specialist_jr_high_specialised_task
  (and (typetask ?tt&:(fuzzy-match ?tt "High"))
       (typeagent ?tag&:(eq ?tag "SPECIALIST Jr."))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " SPECIALIST Jr. AND HIGH SPECIALISED TASK; ")
  )
)


(defrule tech_assist_low_specialized_task
  (and (typetask ?tt&:(fuzzy-match ?tt "Low"))
       (typeagent ?tag&:(or (eq ?tag "TECHNICIAN")
                            (eq ?tag "ASSISTANT")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TECHNICIAN OR ASSISTANT AND LOW SPECIALISED TASK; ")
  )
)

(defrule tech_assist_medium_specialized_task
  (and (typetask ?tt&:(fuzzy-match ?tt "Medium"))
       (typeagent ?tag&:(or (eq ?tag "TECHNICIAN")
                            (eq ?tag "ASSISTANT")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TECHNICIAN OR ASSISTANT AND MEDIUM SPECIALISED TASK; ")
  )
)

(defrule tech_assist_high_specialized_task
  (and (typetask ?tt&:(fuzzy-match ?tt "High"))
       (typeagent ?tag&:(or (eq ?tag "TECHNICIAN")
                            (eq ?tag "ASSISTANT")
                        )
       )
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TECHNICIAN OR ASSISTANT AND HIGH SPECIALISED TASK; ")
  )
)

(defrule defuzzify "low salience to allow all rules to fire and do global contribution"
  (declare (salience -100))
  (change_desire ?chdes)
  (change_interest ?chint)
  (change_disgust ?chdisg)
  (change_anxiety ?chanx)
  (change_stress ?chstrs)
 =>
  (bind ?desire-to-add (?chdes momentDefuzzify))
  (bind ?interest-to-add (?chint momentDefuzzify))
  (bind ?disgust-to-add (?chdisg momentDefuzzify))
  (bind ?anxiety-to-add (?chanx momentDefuzzify))
  (bind ?stress-to-add (?chstrs momentDefuzzify))
  (store SUMDESIRE ?desire-to-add)
  (store SUMINTEREST ?interest-to-add)
  (store SUMDISGUST ?disgust-to-add)
  (store SUMANXIETY ?anxiety-to-add)
  (store SUMSTRESS ?stress-to-add)
  (store RULESTHATFIRED ?*rulesThatFired*)
)
