;***********************************************************************
;Multi-Agent System to Simulate the Human Behaviour within a Work Team
;version 2.0
;
;This is the file with Fuzzy Rules to modify Trust level of a given Agent 
;respect to a specific teammate in a given task. The Trust level is 
;modified using the following inputs:
;  - The current value in the Trust Tendency parameter (of the Agent's teammate)
;  - The Obtained results in the common task(Task Quality and Task Duration)
;  - The current emotional state of the Agent
;
;@author: Juan C. Martinez Miranda.
;         juan.martinez.miranda@gmail.com
;Institution: Universdad Complutense de Madrid
;             Facultad de Informtica.
;Winter 2010.

************************************************************************/


;INPUT VALUES
(defglobal ?*FDesire* = (new nrc.fuzzy.FuzzyVariable "desire" 0.0 100.0))
(defglobal ?*FInterest* = (new nrc.fuzzy.FuzzyVariable "interest" 0.0 100.0))
(defglobal ?*FDisgust* = (new nrc.fuzzy.FuzzyVariable "disgust" 0.0 100.0))
(defglobal ?*FAnxiety* = (new nrc.fuzzy.FuzzyVariable "anxiety" 0.0 100.0))
(defglobal ?*FStress* = (new nrc.fuzzy.FuzzyVariable "stress" 0.0 100.0))
(defglobal ?*FTaskQuality* = (new nrc.fuzzy.FuzzyVariable "taskquality" 0.0 100.0))
(defglobal ?*FTaskDuration* = (new nrc.fuzzy.FuzzyVariable "taskduration" -30.0 30.0))
(defglobal ?*FTrustTendency* = (new nrc.fuzzy.FuzzyVariable "trusttendency" -40.0 40.0))


;OUTPUT VALUE --> Trust Tendency to be used when Trust Level is set.
(defglobal ?*FTrustLevel* = (new nrc.fuzzy.FuzzyVariable "trusttendency" -40.0 40.0 "Intensity"))

(defglobal ?*rulesThatFired* = "")

(defrule init
   (inicio)
  =>
   (import nrc.fuzzy.*)
   (load-package nrc.fuzzy.jess.FuzzyFunctions)
   (?*FDesire* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FDesire* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FDesire* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FInterest* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FInterest* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FInterest* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FDisgust* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FDisgust* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FDisgust* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FAnxiety* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FAnxiety* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FAnxiety* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FStress* addTerm "Low" (new ZFuzzySet 0.0 25.0))
   (?*FStress* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FStress* addTerm "High" (new SFuzzySet 75.0 100.0))
   (?*FTaskQuality* addTerm "Low" (new ZFuzzySet 0.0 15.0))
   (?*FTaskQuality* addTerm "Regular" (new PIFuzzySet 25.0 15.0))
   (?*FTaskQuality* addTerm "Acceptable" (new PIFuzzySet 50.0 15.0))
   (?*FTaskQuality* addTerm "High" (new PIFuzzySet 75.0 15.0))
   (?*FTaskQuality* addTerm "Excelent" (new SFuzzySet 85.0 100.0))
   (?*FTaskDuration* addTerm "HighAdvance" (new ZFuzzySet -30.0 -10.0))
   (?*FTaskDuration* addTerm "LowAdvance" (new PIFuzzySet -7.5 7.5))
   (?*FTaskDuration* addTerm "Normal" (new PIFuzzySet 0.0 5.0))
   (?*FTaskDuration* addTerm "LowDelay" (new PIFuzzySet 7.5 7.5))
   (?*FTaskDuration* addTerm "HighDelay" (new SFuzzySet 10.0 30.0))
   (?*FTrustTendency* addTerm "HighDecrease" (new ZFuzzySet -40.0 -20.0))
   (?*FTrustTendency* addTerm "LowDecrease" (new PIFuzzySet -15.0 15.0))
   (?*FTrustTendency* addTerm "NoChange" (new PIFuzzySet 0.0 10.0))
   (?*FTrustTendency* addTerm "LowIncrease" (new PIFuzzySet 15.0 15.0))
   (?*FTrustTendency* addTerm "HighIncrease" (new SFuzzySet 20.0 40.0))

   (?*FTrustLevel* addTerm "HighDecrease" (new ZFuzzySet -40.0 -20.0))
   (?*FTrustLevel* addTerm "LowDecrease" (new PIFuzzySet -15.0 15.0))
   (?*FTrustLevel* addTerm "NoChange" (new PIFuzzySet 0.0 10.0))
   (?*FTrustLevel* addTerm "LowIncrease" (new PIFuzzySet 15.0 15.0))
   (?*FTrustLevel* addTerm "HighIncrease" (new SFuzzySet 20.0 40.0))

   (store DESIREFUZZYVARIABLE ?*FDesire*)
   (store INTERESTFUZZYVARIABLE ?*FInterest*)
   (store DISGUSTFUZZYVARIABLE ?*FDisgust*)
   (store ANXIETYFUZZYVARIABLE ?*FAnxiety*)
   (store STRESSFUZZYVARIABLE ?*FStress*)
   (store TASKQUALITYFUZZYVARIABLE ?*FTaskQuality*)
   (store TASKDURATIONFUZZYVARIABLE ?*FTaskDuration*)
   (store TRUSTTENDENCYFUZZYVARIABLE ?*FTrustTendency*)
)

;============== SET OF RULES AFECTED BY EMOTINAL STATE =====================

(defrule low_desire
  (desire ?des&:(fuzzy-match ?des "Low"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DESIRE; ")
  )
)

(defrule medium_desire
  (desire ?des&:(fuzzy-match ?des "Medium"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DESIRE; ")
  )
)

(defrule high_desire
  (desire ?des&:(fuzzy-match ?des "High"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DESIRE; ")
  )
)

(defrule low_interest
  (interest ?int&:(fuzzy-match ?int "Low"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW INTEREST; ")
  )
)

(defrule medium_interest
  (interest ?int&:(fuzzy-match ?int "Medium"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM INTEREST; ")
  )
)

(defrule high_interest
  (interest ?int&:(fuzzy-match ?int "High"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH INTEREST; ")
  )
)

(defrule low_anxiety
  (anxiety ?anx&:(fuzzy-match ?anx "Low"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANXIETY; ")
  )
)

(defrule medium_anxiety
  (anxiety ?anx&:(fuzzy-match ?anx "Medium"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANXIETY; ")
  )
)

(defrule high_anxiety
  (anxiety ?anx&:(fuzzy-match ?anx "High"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANXIETY; ")
  )
)

(defrule low_disgust
  (disgust ?dis&:(fuzzy-match ?dis "Low"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DISGUST; ")
  )
)

(defrule medium_disgust
  (disgust ?dis&:(fuzzy-match ?dis "Medium"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DISGUST; ")
  )
)

(defrule high_disgust
  (disgust ?dis&:(fuzzy-match ?dis "High"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DISGUST; ")
  )
)

(defrule low_stress
  (stress ?strs&:(fuzzy-match ?strs "Low"))
 =>
  ;(assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW STRESS; ")
  )
)

(defrule medium_stress
  (stress ?strs&:(fuzzy-match ?strs "Medium"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM STRESS; ")
  )
)

(defrule high_stress
  (stress ?strs&:(fuzzy-match ?strs "High"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH STRESS; ")
  )
)

;=== SET OF RULES AFECTED BY OBTAINED RESULTS (QUALITY AND DURATION) IN THE TASK =====

(defrule low_task_quality
  (taskquality ?tskqty&:(fuzzy-match ?tskqty "Low"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW TASK QUALITY; ")
  )
)

(defrule regular_task_quality
  (taskquality ?tskqty&:(fuzzy-match ?tskqty "Regular"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " REGULAR TASK QUALITY; ")
  )
)

(defrule acceptable_task_quality
  (taskquality ?tskqty&:(fuzzy-match ?tskqty "Acceptable"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " ACCEPTABLE TASK QUALITY; ")
  )
)

(defrule high_task_quality
  (taskquality ?tskqty&:(fuzzy-match ?tskqty "High"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH TASK QUALITY; ")
  )
)

(defrule excelent_task_quality
  (taskquality ?tskqty&:(fuzzy-match ?tskqty "Excelent"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " EXCELENT TASK QUALITY; ")
  )
)

(defrule high_delay_task
  (taskduration ?tskdur&:(fuzzy-match ?tskdur "HighDelay"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DELAY IN TASK; ")
  )
)

(defrule low_delay_task
  (taskduration ?tskdur&:(fuzzy-match ?tskdur "LowDelay"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DELAY IN TASK; ")
  )
)

(defrule normal_task_duration
  (taskduration ?tskdur&:(fuzzy-match ?tskdur "Normal"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " NORMAL TASK DURATION; ")
  )
)

(defrule low_advance_task
  (taskduration ?tskdur&:(fuzzy-match ?tskdur "LowAdvance"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ADVANCE IN TASK; ")
  )
)

(defrule high_advance_task
  (taskduration ?tskdur&:(fuzzy-match ?tskdur "HighAdvance"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ADVANCE IN TASK; ")
  )
)

;========== SET OF RULES AFECTED BY CURRENT TRUST TENDENCY VALUE =============

(defrule trust_tendency_high_decrease
  (trusttendency ?trsttdcy&:(fuzzy-match ?trsttdcy "HighDecrease"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TRUST TENDENCY HIGH DECREASE; ")
  )
)

(defrule trust_tendency_low_decrease
  (trusttendency ?trsttdcy&:(fuzzy-match ?trsttdcy "LowDecrease"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TRUST TENDENCY LOW DECREASE; ")
  )
)

(defrule trust_tendency_no_changes
  (trusttendency ?trsttdcy&:(fuzzy-match ?trsttdcy "NoChange"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TRUST TENDENCY NO CHANGE; ")
  )
)

(defrule trust_tendency_low_increase
  (trusttendency ?trsttdcy&:(fuzzy-match ?trsttdcy "LowIncrease"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TRUST TENDENCY LOW INCREASE; ")
  )
)

(defrule trust_tendency_high_increase
  (trusttendency ?trsttdcy&:(fuzzy-match ?trsttdcy "HighIncrease"))
 =>
  (assert (change_trust_level (new FuzzyValue ?*FTrustLevel* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " TRUST TENDENCY HIGH INCREASE; ")
  )
)


(defrule defuzzify "low salience to allow all rules to fire and do global contribution"
  (declare (salience -100))
  (change_trust_level ?chtl)
 =>
  (bind ?tl-to-add (?chtl momentDefuzzify))
  (store TRSTLEVEL ?tl-to-add)
  (store RULESTHATFIRED ?*rulesThatFired*)
)
