;***********************************************************************
;Multi-Agent System to Simulate the Human Behaviour within a Team Work
;version 2.0
;
;This is the file with Fuzzy Rules to change the level of the Trust Tendency 
;parameter. The Trust Tendency is used to later increase the Trust level of the
;Agent respect to its teammates in a specific task.
;
;@author: Juan C. Martinez Miranda.
;         juan.martinez.miranda@gmail.com
;Institution: Universdad Complutense de Madrid
;             Facultad de Informtica.
;Winter 2010.

************************************************************************/


;INPUT VALUES
(defglobal ?*FDrive* = (new nrc.fuzzy.FuzzyVariable "drive" 0.0 100.0))
(defglobal ?*FInfluence* = (new nrc.fuzzy.FuzzyVariable "influence" 0.0 100.0))
(defglobal ?*FSteadiness* = (new nrc.fuzzy.FuzzyVariable "steadiness" 0.0 100.0))
(defglobal ?*FCompliance* = (new nrc.fuzzy.FuzzyVariable "compliance" 0.0 100.0))
(defglobal ?*FDesire* = (new nrc.fuzzy.FuzzyVariable "desire" 0.0 100.0))
(defglobal ?*FInterest* = (new nrc.fuzzy.FuzzyVariable "interest" 0.0 100.0))
(defglobal ?*FDisgust* = (new nrc.fuzzy.FuzzyVariable "disgust" 0.0 100.0))
(defglobal ?*FAnxiety* = (new nrc.fuzzy.FuzzyVariable "anxiety" 0.0 100.0))
(defglobal ?*FStress* = (new nrc.fuzzy.FuzzyVariable "stress" 0.0 100.0))
(defglobal ?*FTrust* = (new nrc.fuzzy.FuzzyVariable "trustlevel" 0.0 50.0))

;OUTPUT VALUE --> Trust Tendency to be used when Trust Level is set.
(defglobal ?*FTrustTendency* = (new nrc.fuzzy.FuzzyVariable "trusttendency" -40.0 40.0 "Intensity"))

(defglobal ?*rulesThatFired* = "")

(defrule init
   (inicio)
  =>
   (import nrc.fuzzy.*)
   (load-package nrc.fuzzy.jess.FuzzyFunctions)
   (?*FDrive* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FDrive* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FDrive* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FInfluence* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FInfluence* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FInfluence* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FSteadiness* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FSteadiness* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FSteadiness* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FCompliance* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FCompliance* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FCompliance* addTerm "High" (new SFuzzySet 60.0 100.0))
   (?*FDesire* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FDesire* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FDesire* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FInterest* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FInterest* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FInterest* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FDisgust* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FDisgust* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FDisgust* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FAnxiety* addTerm "Low" (new ZFuzzySet 0.0 35.0))
   (?*FAnxiety* addTerm "Medium" (new PIFuzzySet 50.0 25.0))
   (?*FAnxiety* addTerm "High" (new SFuzzySet 65.0 100.0))
   (?*FStress* addTerm "Low" (new ZFuzzySet 0.0 25.0))
   (?*FStress* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FStress* addTerm "High" (new SFuzzySet 75.0 100.0))
   (?*FTrust* addTerm "Low" (new ZFuzzySet 0.0 20.0))
   (?*FTrust* addTerm "Medium" (new PIFuzzySet 25.0 15.0))
   (?*FTrust* addTerm "High" (new SFuzzySet 30.0 50.0))


   (?*FTrustTendency* addTerm "HighDecrease" (new ZFuzzySet -40.0 -20.0))
   (?*FTrustTendency* addTerm "LowDecrease" (new PIFuzzySet -15.0 15.0))
   (?*FTrustTendency* addTerm "NoChange" (new PIFuzzySet 0.0 10.0))
   (?*FTrustTendency* addTerm "LowIncrease" (new PIFuzzySet 15.0 15.0))
   (?*FTrustTendency* addTerm "HighIncrease" (new SFuzzySet 20.0 40.0))

   (store DRIVEFUZZYVARIABLE ?*FDrive*)
   (store INFLUENCEFUZZYVARIABLE ?*FInfluence*)
   (store STEADINESSFUZZYVARIABLE ?*FSteadiness*)
   (store COMPLIANCEFUZZYVARIABLE ?*FCompliance*)
   (store DESIREFUZZYVARIABLE ?*FDesire*)
   (store INTERESTFUZZYVARIABLE ?*FInterest*)
   (store DISGUSTFUZZYVARIABLE ?*FDisgust*)
   (store ANXIETYFUZZYVARIABLE ?*FAnxiety*)
   (store STRESSFUZZYVARIABLE ?*FStress*)
   (store TRUSTLEVELVARIABLE ?*FTrust*)
)

(defrule low_desire
  (desire ?des&:(fuzzy-match ?des "Low"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DESIRE; ")
  )
)

(defrule medium_desire
  (desire ?des&:(fuzzy-match ?des "Medium"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DESIRE; ")
  )
)

(defrule high_desire
  (desire ?des&:(fuzzy-match ?des "High"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DESIRE; ")
  )
)

(defrule low_interest
  (interest ?int&:(fuzzy-match ?int "Low"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW INTEREST; ")
  )
)

(defrule medium_interest
  (interest ?int&:(fuzzy-match ?int "Medium"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM INTEREST; ")
  )
)

(defrule high_interest
  (interest ?int&:(fuzzy-match ?int "High"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH INTEREST; ")
  )
)

(defrule low_anxiety
  (anxiety ?anx&:(fuzzy-match ?anx "Low"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANXIETY; ")
  )
)

(defrule medium_anxiety
  (anxiety ?anx&:(fuzzy-match ?anx "Medium"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANXIETY; ")
  )
)

(defrule high_anxiety
  (anxiety ?anx&:(fuzzy-match ?anx "High"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANXIETY; ")
  )
)

(defrule low_disgust
  (disgust ?dis&:(fuzzy-match ?dis "Low"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DISGUST; ")
  )
)

(defrule medium_disgust
  (disgust ?dis&:(fuzzy-match ?dis "Medium"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DISGUST; ")
  )
)

(defrule high_disgust
  (disgust ?dis&:(fuzzy-match ?dis "High"))
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DISGUST; ")
  )
)

(defrule low_drive
  (and (drive ?dr&:(fuzzy-match ?dr "Low"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER PERSONALITY; ")
  )
)

(defrule medium_drive
  (and (drive ?dr&:(fuzzy-match ?dr "Medium"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER PERSONALITY; ")
  )
)

(defrule high_drive
  (and (drive ?dr&:(fuzzy-match ?dr "High"))
	 (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER PERSONALITY; ")
  )
)

(defrule low_influence
  (and (influence ?inf&:(fuzzy-match ?inf "Low"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE PERSONALITY; ")
  )
)

(defrule medium_influence
  (and (influence ?inf&:(fuzzy-match ?inf "Medium"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE PERSONALITY; ")
  )
)

(defrule high_influence
  (and (influence ?inf&:(fuzzy-match ?inf "High"))
	 (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE PERSONALITY; ")
  )
)

(defrule low_steadiness
  (and (steadiness ?stead&:(fuzzy-match ?stead "Low"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE PERSONALITY; ")
  )
)

(defrule medium_steadiness
  (and (steadiness ?stead&:(fuzzy-match ?stead "Medium"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE PERSONALITY; ")
  )
)

(defrule high_steadiness
  (and (steadiness ?stead&:(fuzzy-match ?stead "High"))
	 (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE PERSONALITY; ")
  )
)

(defrule low_compliance
  (and (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL PERSONALITY; ")
  )
)

(defrule medium_compliance
  (and (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
       (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL PERSONALITY; ")
  )
)

(defrule high_compliance
  (and (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
	 (firstinteraction ?frstint&:(= ?frstint 1))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "LowIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL PERSONALITY; ")
  )
)


(defrule low_current_trust_level
  (and (trustlevel ?trstlvl&:(fuzzy-match ?trstlvl "Low"))
       (firstinteraction ?frstint&:(= ?frstint 0))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighDecrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW CURRENT TRUST LEVEL; ")
  )
)

(defrule medium_current_trust_level
  (and (trustlevel ?trstlvl&:(fuzzy-match ?trstlvl "Medium"))
       (firstinteraction ?frstint&:(= ?frstint 0))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "NoChange"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM CURRENT TRUST LEVEL; ")
  )
)

(defrule high_current_trust_level
  (and (trustlevel ?trstlvl&:(fuzzy-match ?trstlvl "High"))
	 (firstinteraction ?frstint&:(= ?frstint 0))
  )
 =>
  (assert (change_trust_tendency (new FuzzyValue ?*FTrustTendency* "HighIncrease"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH CURRENT TRUST LEVEL; ")
  )
)


(defrule defuzzify "low salience to allow all rules to fire and do global contribution"
  (declare (salience -100))
  (change_trust_tendency ?chtt)
 =>
  (bind ?tt-to-add (?chtt momentDefuzzify))
  (store TT ?tt-to-add)
  (store RULESTHATFIRED ?*rulesThatFired*)
)
