;***********************************************************************
;Multi-Agent System to Simulate the Human Behaviour within a Team Work
;version 2.0
;
;This is the file with Fuzzy Rules to change the Internal State of the Agent
;according to the Assigned Quality Tasks Parameter.
;
;@author: Juan C. Martinez Miranda.
;         juan.martinez.miranda@gmail.com
;Institution: Universdad Complutense de Madrid
;             Facultad de Informtica.
;Winter 2010.

************************************************************************/

(defglobal ?*FDrive* = (new nrc.fuzzy.FuzzyVariable "drive" 0.0 100.0))
(defglobal ?*FInfluence* = (new nrc.fuzzy.FuzzyVariable "influence" 0.0 100.0))
(defglobal ?*FStainess* = (new nrc.fuzzy.FuzzyVariable "stainess" 0.0 100.0))
(defglobal ?*FCompliance* = (new nrc.fuzzy.FuzzyVariable "compliance" 0.0 100.0))
(defglobal ?*FGoalsAchievement* = (new nrc.fuzzy.FuzzyVariable "goalseachievement" 0.0 100.0))
(defglobal ?*FDuration* = (new nrc.fuzzy.FuzzyVariable "duration" -30.0 30.0))
(defglobal ?*FAgentContribution* = (new nrc.fuzzy.FuzzyVariable "agentcontribution" 0.0 100.0))
(defglobal ?*FQuality* = (new nrc.fuzzy.FuzzyVariable "quality" 0.0 100.0))

(defglobal ?*ChangeDesire* = (new nrc.fuzzy.FuzzyVariable "ChangeDesire" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeInterest* = (new nrc.fuzzy.FuzzyVariable "ChangeInterest" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeDisgust* = (new nrc.fuzzy.FuzzyVariable "ChangeDisgust" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeAnxiety* = (new nrc.fuzzy.FuzzyVariable "ChangeAnxiety" -30.0 30.0 "Intensity"))
(defglobal ?*ChangeStress* = (new nrc.fuzzy.FuzzyVariable "ChangeStress" -30.0 30.0 "Intensity"))

(defglobal ?*rulesThatFired* = "")

(defrule init
   (inicio)
  =>
   (import nrc.fuzzy.*)
   (load-package nrc.fuzzy.jess.FuzzyFunctions)
   (?*FQuality* addTerm "Low" (new ZFuzzySet 0.0 15.0))
   (?*FQuality* addTerm "Regular" (new PIFuzzySet 25.0 15.0))
   (?*FQuality* addTerm "Acceptable" (new PIFuzzySet 50.0 15.0))
   (?*FQuality* addTerm "High" (new PIFuzzySet 75.0 15.0))
   (?*FQuality* addTerm "Excelent" (new SFuzzySet 85.0 100.0))

   (?*FGoalsAchievement* addTerm "VeryLow" (new ZFuzzySet 0.0 30.0))
   (?*FGoalsAchievement* addTerm "Low" (new PIFuzzySet 40.0 15.0))
   (?*FGoalsAchievement* addTerm "Minimum" (new PIFuzzySet 60.0 15.0))
   (?*FGoalsAchievement* addTerm "Acceptable" (new PIFuzzySet 80.0 15.0))
   (?*FGoalsAchievement* addTerm "Satisfactory" (new SFuzzySet 90.0 100.0))

   (?*FDuration* addTerm "HighAdvance" (new ZFuzzySet -30.0 -10.0))
   (?*FDuration* addTerm "LowAdvance" (new PIFuzzySet -7.5 7.5))
   (?*FDuration* addTerm "Normal" (new PIFuzzySet 0.0 5.0))
   (?*FDuration* addTerm "LowDelay" (new PIFuzzySet 7.5 7.5))
   (?*FDuration* addTerm "HighDelay" (new SFuzzySet 10.0 30.0))

   (?*FAgentContribution* addTerm "Low" (new ZFuzzySet 0.0 25.0))
   (?*FAgentContribution* addTerm "Regular" (new PIFuzzySet 30.0 10.0))
   (?*FAgentContribution* addTerm "Acceptable" (new PIFuzzySet 50.0 15.0))
   (?*FAgentContribution* addTerm "High" (new PIFuzzySet 70.0 10.0))
   (?*FAgentContribution* addTerm "Excelent" (new SFuzzySet 75.0 100.0))

   (?*FDrive* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FDrive* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FDrive* addTerm "High" (new SFuzzySet 60.0 100.0))

   (?*FInfluence* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FInfluence* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FInfluence* addTerm "High" (new SFuzzySet 60.0 100.0))

   (?*FStainess* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FStainess* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FStainess* addTerm "High" (new SFuzzySet 60.0 100.0))

   (?*FCompliance* addTerm "Low" (new ZFuzzySet 0.0 40.0))
   (?*FCompliance* addTerm "Medium" (new PIFuzzySet 50.0 30.0))
   (?*FCompliance* addTerm "High" (new SFuzzySet 60.0 100.0))

   (?*ChangeDesire* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeDesire* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeDesire* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeDesire* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeDesire* addTerm "HighUp" (new SFuzzySet 15.0 30.0))

   (?*ChangeInterest* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeInterest* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeInterest* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeInterest* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeInterest* addTerm "HighUp" (new SFuzzySet 15.0 30.0))

   (?*ChangeDisgust* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeDisgust* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeDisgust* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeDisgust* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeDisgust* addTerm "HighUp" (new SFuzzySet 15.0 30.0))

   (?*ChangeAnxiety* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeAnxiety* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeAnxiety* addTerm "Equal" (new PIFuzzySet 0.0 10.0))
   (?*ChangeAnxiety* addTerm "Up" (new PIFuzzySet 10.0 10.0))
   (?*ChangeAnxiety* addTerm "HighUp" (new SFuzzySet 15.0 30.0))

   (?*ChangeStress* addTerm "HighDown" (new ZFuzzySet -30.0 -15.0))
   (?*ChangeStress* addTerm "Down" (new PIFuzzySet -10.0 10.0))
   (?*ChangeStress* addTerm "Equal" (new PIFuzzySet 10.0 10.0))
   (?*ChangeStress* addTerm "Up" (new PIFuzzySet 10.0 10.0 ))
   (?*ChangeStress* addTerm "HighUp" (new SFuzzySet 15.0 30.0))

   (store QUALITYFUZZYVARIABLE ?*FQuality*)
   (store GOALACHIEVEMENTFUZZYVARIABLE ?*FGoalsAchievement*)
   (store TASKDURATIONFUZZYVARIABLE ?*FDuration*)
   (store AGENTCONTRIBUTIONFUZZYVARIABLE ?*FAgentContribution*)
   (store DRIVEFUZZYVARIABLE ?*FDrive*)
   (store INFLUENCEFUZZYVARIABLE ?*FInfluence*)
   (store STAINESSFUZZYVARIABLE ?*FStainess*)
   (store COMPLIANCEFUZZYVARIABLE ?*FCompliance*)

)

(defrule low_quality_high_drive
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_high_drive
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_high_drive
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_high_drive
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_high_drive
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_medium_drive
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_medium_drive
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_medium_drive
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_medium_drive
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_medium_drive
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_low_drive
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_low_drive
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_low_drive
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_low_drive
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_low_drive
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_high_influence
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_high_influence
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_high_influence
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_high_influence
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_high_influence
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_medium_influence
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_medium_influence
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_medium_influence
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_medium_influence
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_medium_influence
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_low_influence
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighDown"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_low_influence
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_low_influence
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_low_influence
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_low_influence
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_high_stainess
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_high_stainess
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_high_stainess
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_high_stainess
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_high_stainess
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_medium_stainess
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_medium_stainess
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_medium_stainess
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_medium_stainess
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_medium_stainess
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_low_stainess
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_low_stainess
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_low_stainess
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_low_stainess
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_low_stainess
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_high_compliance
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_high_compliance
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_high_compliance
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_high_compliance
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_high_compliance
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_medium_compliance
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_medium_compliance
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_medium_compliance
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_medium_compliance
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_medium_compliance
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH EXCELENT QUALITY; ")
  )
)

(defrule low_quality_low_compliance
  (and (quality ?q&:(fuzzy-match ?q "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH LOW QUALITY; ")
  )
)

(defrule regular_quality_low_compliance
  (and (quality ?q&:(fuzzy-match ?q "Regular"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH REGULAR QUALITY; ")
  )
)

(defrule acceptable_quality_low_compliance
  (and (quality ?q&:(fuzzy-match ?q "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH ACCEPTABLE QUALITY; ")
  )
)

(defrule high_quality_low_compliance
  (and (quality ?q&:(fuzzy-match ?q "High"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH HIGH QUALITY; ")
  )
)

(defrule excelent_quality_low_compliance
  (and (quality ?q&:(fuzzy-match ?q "Excelent"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH EXCELENT QUALITY; ")
  )
)

(defrule very_low_goals_achieve_high_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_high_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_high_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_high_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_high_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_medium_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_medium_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_medium_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_medium_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_medium_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_low_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_low_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_low_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_low_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_low_drive
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_high_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_high_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_high_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_high_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_high_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_medium_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_medium_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_medium_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_medium_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_medium_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_low_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_low_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_low_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_low_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_low_influence
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_high_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_high_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_high_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_high_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_high_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_medium_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_medium_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_medium_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_medium_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_medium_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_low_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_low_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_low_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_low_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_low_stainess
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_high_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_high_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_high_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_high_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_high_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_medium_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_medium_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_medium_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_medium_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_medium_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule very_low_goals_achieve_low_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Very Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH VERY LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule low_goals_achieve_low_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH LOW GOALS ACHIEVEMENT; ")
  )
)

(defrule minimum_goals_achieve_low_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Minimum"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH MINIMUM GOALS ACHIEVEMENT; ")
  )
)

(defrule acceptable_goals_achieve_low_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH ACCEPTABLE GOALS ACHIEVEMENT; ")
  )
)

(defrule satisfactory_goals_achieve_low_compliance
  (and (goalsachievement ?gach&:(fuzzy-match ?gach "Satisfactory"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH SATISFACTORY GOALS ACHIEVEMENT; ")
  )
)

(defrule low_taskduration_high_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_high_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_high_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_high_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_high_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_medium_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_medium_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_medium_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_medium_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_medium_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_low_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_low_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_low_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_low_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_low_drive
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_high_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_high_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_high_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_high_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_high_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_medium_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_medium_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_medium_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_medium_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_medium_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_low_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_low_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_low_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_low_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_low_influence
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_high_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_high_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_high_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_high_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_high_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_medium_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_medium_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_medium_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_medium_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_medium_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_low_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_low_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_low_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_low_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_low_stainess
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_high_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_high_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_high_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_high_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_high_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_medium_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_medium_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_medium_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_medium_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_medium_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_taskduration_low_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH LOW RESULTS OPPORTUNITY; ")
  )
)

(defrule regular_taskduration_low_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowDelay"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH REGULAR RESULTS OPPORTUNITY; ")
  )
)

(defrule acceptable_taskduration_low_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "Normal"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH ACCEPTABLE RESULTS OPPORTUNITY; ")
  )
)

(defrule high_taskduration_low_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "LowAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH HIGH RESULTS OPPORTUNITY; ")
  )
)

(defrule excelent_taskduration_low_compliance
  (and (taskduration ?tsd&:(fuzzy-match ?tsd "HighAdvance"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH EXCELENT RESULTS OPPORTUNITY; ")
  )
)

(defrule low_agent_contribution_high_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_high_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_high_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_high_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_high_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (drive ?dr&:(fuzzy-match ?dr "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH DRIVER WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_medium_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_medium_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_medium_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_medium_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_medium_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (drive ?dr&:(fuzzy-match ?dr "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM DRIVER WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_low_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_low_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_low_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_low_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_low_drive
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (drive ?dr&:(fuzzy-match ?dr "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW DRIVER WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_high_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_high_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_high_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_high_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_high_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (influence ?inf&:(fuzzy-match ?inf "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH EXPRESSIVE WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_medium_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_medium_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_medium_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_medium_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_medium_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (influence ?inf&:(fuzzy-match ?inf "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM EXPRESSIVE WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_low_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_low_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_low_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_low_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_low_influence
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (influence ?inf&:(fuzzy-match ?inf "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW EXPRESSIVE WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_high_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_high_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_high_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_high_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_high_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (stainess ?stss&:(fuzzy-match ?stss "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH AMIABLE WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_medium_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_medium_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_medium_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_medium_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_medium_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (stainess ?stss&:(fuzzy-match ?stss "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM AMIABLE WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_low_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighUp"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighUp"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_low_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_low_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_low_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_low_stainess
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (stainess ?stss&:(fuzzy-match ?stss "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW AMIABLE WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_high_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "HighUp"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "HighUp"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighUp"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_high_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_high_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_high_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Down"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_high_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "High"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " HIGH ANALYTICAL WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_medium_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_medium_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_medium_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_medium_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Down"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_medium_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Medium"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Down"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " MEDIUM ANALYTICAL WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule low_agent_contribution_low_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Low"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Down"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Down"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Up"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH LOW INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule regular_agent_contribution_low_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Regular"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Up"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Up"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH REGULAR INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule acceptable_agent_contribution_low_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Acceptable"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "Equal"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "Equal"))
          (change_stress (new FuzzyValue ?*ChangeStress* "Equal"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH ACCEPTABLE INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule high_agent_contribution_low_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "High"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Equal"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Equal"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH HIGH INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule excelent_agent_contribution_low_compliance
  (and (agentcontribution ?agc&:(fuzzy-match ?agc "Excelent"))
       (compliance ?cmpl&:(fuzzy-match ?cmpl "Low"))
  )
 =>
  (assert (change_desire (new FuzzyValue ?*ChangeDesire* "Up"))
          (change_interest (new FuzzyValue ?*ChangeInterest* "Up"))
          (change_disgust (new FuzzyValue ?*ChangeDisgust* "HighDown"))
          (change_anxiety (new FuzzyValue ?*ChangeAnxiety* "HighDown"))
          (change_stress (new FuzzyValue ?*ChangeStress* "HighDown"))
  )
  (bind ?*rulesThatFired* (str-cat ?*rulesThatFired*
        " LOW ANALYTICAL WITH EXCELENT INDIVIDUAL CONTRIBUTION; ")
  )
)

(defrule defuzzify "low salience to allow all rules to fire and do global contribution"
  (declare (salience -100))
  (change_desire ?chdes)
  (change_interest ?chint)
  (change_disgust ?chdisg)
  (change_anxiety ?chanx)
  (change_stress ?chstrs)
 =>
  (bind ?desire-to-add (?chdes momentDefuzzify))
  (bind ?interest-to-add (?chint momentDefuzzify))
  (bind ?disgust-to-add (?chdisg momentDefuzzify))
  (bind ?anxiety-to-add (?chanx momentDefuzzify))
  (bind ?stress-to-add (?chstrs momentDefuzzify))
  (store SUMDESIRE ?desire-to-add)
  (store SUMINTEREST ?interest-to-add)
  (store SUMDISGUST ?disgust-to-add)
  (store SUMANXIETY ?anxiety-to-add)
  (store SUMSTRESS ?stress-to-add)
  (store RULESTHATFIRED ?*rulesThatFired*)
)
